summaryrefslogtreecommitdiff
path: root/jstests/replsets/rollback_dropdb.js
diff options
context:
space:
mode:
authorEric Milkie <milkie@10gen.com>2014-09-12 12:27:19 -0400
committerEric Milkie <milkie@10gen.com>2014-09-12 16:48:33 -0400
commitf7a403b6ef67f6870adde252cf2dd794e8c1604b (patch)
tree54f3c89489828ae7735e7dac0b909eb01d2c5eff /jstests/replsets/rollback_dropdb.js
parente079496c239748c95136458c85c23478ee609fdb (diff)
downloadmongo-f7a403b6ef67f6870adde252cf2dd794e8c1604b.tar.gz
SERVER-15089 remove fatal state and refactor rollback to use replcoord
Diffstat (limited to 'jstests/replsets/rollback_dropdb.js')
-rw-r--r--jstests/replsets/rollback_dropdb.js13
1 files changed, 4 insertions, 9 deletions
diff --git a/jstests/replsets/rollback_dropdb.js b/jstests/replsets/rollback_dropdb.js
index fc7861eb7c4..24505dbfd36 100644
--- a/jstests/replsets/rollback_dropdb.js
+++ b/jstests/replsets/rollback_dropdb.js
@@ -42,16 +42,11 @@ assert(a_conn.host === master.host, "a_conn assumed to be master");
options = {writeConcern: {w: 1, wtimeout: 60000}, upsert: true};
assert.writeOK(a_conn.getDB(name).foo.insert({x: 2}, options));
-// restart B, which should rollback and go FATAL
+// restart B, which should attempt rollback but then fassert
+clearRawMongoProgramOutput();
replTest.restart(BID);
assert.soon(function() {
- try {
- var res = b_conn.getDB("admin").runCommand({replSetGetStatus: 1});
- return res.myState === 4; // 4 is FATAL
- }
- catch (e) {
- return false;
- }
-}, "B failed to go FATAL");
+ return rawMongoProgramOutput().match("replSet error rollback : can't rollback drop database full resync will be required");
+}, "B failed to fassert");
replTest.stopSet();